<?php
$page_title = "API Signature Settings";
include_once('template/base_head.php');
?>
			<!-- サイドバー -->
			<aside id="colLeft">
				<h1><a href=""><img src="../img/logo.png" alt="iWallet"></a></h1>
				<div class="aside-heading">
					&nbsp;
				</div>
				&nbsp;
			</aside>
			<!-- /サイドバー -->
			<!-- メインカラム -->
			<div id="colMain">
				<div class="mainIn">
<?php include_once('template/base_nav.php'); ?>
					<article>
						<div class="article-heading">
							<h2><?php echo $page_title; ?></h2>
						</div>
						<form id="acForm" action="" method="post">
							<table class="table col bdr default odd w60p fontXS m_auto mb20">
								<colgroup>
									<col class="w40p">
									<col class="w60p">
								</colgroup>
								<tr>
									<th>Account Number</th>
									<td><?php $this -> echoUserAccount(); ?></td>
								</tr>
								<tr>
									<th>Name</th>
									<td><?php $this -> echoLastName(); ?> <?php $this -> echoFirstName(); ?></td>
								</tr>
								<tr>
									<th>API Signature</th>
									<td><?php $this -> echoUserName(); ?></td>
								</tr>
								<tr>
									<th>API Password</th>
									<td><?php $this -> echoPassword(); ?></td>
								</tr>
								<tr>
									<th>IP Address</th>
									<td><?php $this -> echoIpAddress(); ?></td>
								</tr>
								<tr>
									<th>Domain Name</th>
									<td><?php $this -> echoDomainName(); ?></td>
								</tr>
								<tr>
									<th>Validation Settings</th>
									<td><?php $this -> echoWhitelistSettingsCheckboxes(true); ?></td>
								</tr>
							</table>

							<input type="hidden" value="action" id="type" name="type" />
							<input type="hidden" value="<?php $this -> echoUserAccount(); ?>" id="user_account" name="user_account" />
							<input type="hidden" value="<?php $this -> echoUserName(); ?>" id="user_name" name="user_name" />
							<input type="hidden" value="<?php $this -> echoPassword(); ?>" id="password" name="password" />
							<input type="hidden" value="<?php $this -> echoIpAddress(); ?>" id="ip_address" name="ip_address" />
							<input type="hidden" value="<?php $this -> echoDomainName(); ?>" id="domain_name" name="domain_name" />
							
							<!-- Language Transition Data (Anton) 04/23/2016 -->
							<input class="lang-trans-data" type="hidden" id="lang_data_action" value="/api_signature"/>
							<input class="lang-trans-data" type="hidden" id="lang_data_form" value="#acForm"/>
							<input class="lang-trans-data" type="hidden" id="lang_data_type" value="confirm"/>
							<!-- /Language Transition Data -->
						</form>
						<p class="calign">
							<a href="javascript:actionInput();" class="btn bg-default">&laquo; Back</a>&emsp;
							<input type="button" id="btnComplete" value="Register" class="btn bg-grad px80 hi25">
						</p>
						<div class="article-bottom">
						</div>
					</article>
				</div>
			</div>
			<!-- /メインカラム -->
		</div>
<?php include_once('template/base_foot.php'); ?>
	</div>

	<script src="../js/api_signature.js"></script>
</body>
</html>
